aboutsummaryrefslogtreecommitdiffstats
path: root/users
diff options
context:
space:
mode:
Diffstat (limited to 'users')
-rw-r--r--users/arpit/default.nix1
-rw-r--r--users/arpit/private.example.nix7
2 files changed, 2 insertions, 6 deletions
diff --git a/users/arpit/default.nix b/users/arpit/default.nix
index 9348884..e21b280 100644
--- a/users/arpit/default.nix
+++ b/users/arpit/default.nix
@@ -65,7 +65,6 @@
# Security
security.gopass.enable = true;
- security.gopass.ssh-agent.enable = true;
security.gopass.sync.enable = true;
security.gpg.enable = true;
security.gpg.backup.enable = true;
diff --git a/users/arpit/private.example.nix b/users/arpit/private.example.nix
index 77e5f54..2f169d9 100644
--- a/users/arpit/private.example.nix
+++ b/users/arpit/private.example.nix
@@ -38,11 +38,8 @@
};
};
- # SSH keys to load from gopass (entries under ssh/ in the gopass store)
- config.security.ssh.gopassKeys = [
- "github"
- "gitlab"
- ];
+ # SSH key to load into the gpg-agent from gopass (entry in the gopass store)
+ config.security.ssh.sshKeyGopassPath = "ssh/hostname/username";
# Gopass - Template for configuring gopass, specially syncing
config.security.gopass.sync = {